#!/usr/bin/env python

# simple script to hack together python __doc__ support in swig-generated
# C source files

import sys
import string
import re
import os

if len(sys.argv)<2:
    print 'usage: docify.py <swig-generated .c wrapper file>'
    sys.exit(1)

f=open(sys.argv[1],'r')
outfile=open('%s.tmp' % sys.argv[1],'w')

data=f.readlines()

for i in xrange(0,len(data)):
    outfile.write(data[i])
    match=re.search('^static PyMethodDef SwigMethods',data[i])
    if match:
        #print match.group(0)
        break

if not match:
    raise 'source file does not look like swigged code: ' + argv[1]

pymeths=[]
for i in xrange (i,len(data)):
    if re.search('^.*\{.*NULL.*NULL.*\}', data[i]):
        break
    pymeths.append(data[i])

for line in pymeths:
    match=re.search('^.*char \*.*\".*\"',line)
    if match:
        fname=re.search('\".*\"',match.group(0)).group(0)[1:-1]
        if re.search('swigregister',fname):
      #      print 'skipping doc string for %s\n' % fname
            outfile.write(line)
            continue
   #      print fname
        outfile.write('\t{ (char *)\"%s\", _wrap_%s, METH_VARARGS, _doc_%s },\n' % 
                      (fname, fname, fname))

for i in xrange (i,len(data)):
    outfile.write(data[i])

outfile.close()
f.close()

os.system('mv %s.tmp %s' % (sys.argv[1], sys.argv[1]))
# vim:set ts=4 sw=4 et:



#!/usr/bin/env python
# This adds __doc__ lines to methods in swig-generated .py code.
# simple script to hack together python __doc__ support in swig-generated
# .py shadow class source files

import sys
import string
import re
import os



if len(sys.argv)<2:
    print 'usage: docify.py <swig-generated .py shadow class file>'
    sys.exit(1)

f=open(sys.argv[1],'r')
outfile=open('%s.tmp' % sys.argv[1],'w')

data=f.readlines()
#############################################################################
#for i in xrange(0,len(data)):
#    match=re.search('^.*def __del__',data[i])
#    if match:
#        #print match.group(0)
#        i=i+1
#        break
#
#if not match:
#    # One more chance to find __del__...
#    # This may be a more recent version of SWIG.
#    # Older versions generated __del__ methods.
#    # Newer versions appear to assign a lambda to __del__.
#    for i in xrange(0,len(data)):
#        match=re.search('^\s*__del__\s*=\s*lambda',data[i])
#        if match:
#            #print match.group(0)
#            i=i+1
#            break
#    if not match:
#        raise 'source file does not look like swigged shadow class code: '+sys.argv[1]
#
## read ahead to next def statement
#for i in xrange (i,len(data)):
#    if re.search('^\s*def', data[i]):
#        break
#
#pymeths=[]
#for i in xrange (i,len(data)):
#    if re.search('^\s*def __repr__', data[i]):
#        break
#    pymeths.append(data[i])
#
# I think that the above code can be replaced with the following and it will work
# on both old-style and new-style SWIG.

# collect all the lines that have public method names.
pymeths=[]
for i in xrange (0,len(data)):
    #if re.search('^\s*def\s+[^(]*', data[i]) and not re.search('^\s*def __repr__', data[i]) and not re.search('.*__del__.*', data[i]):
    if re.search('^\s*def\s+[^(]*', data[i]) and not re.search('^\s*def __.*', data[i]):
        pymeths.append(data[i])
#############################################################################

# Make a dictionary of all the method names from the method lines.
methods={}
for line in pymeths:
    methmatch=re.search('def +([^ (]*) *\(\*args\)',line)
    fnmatch=re.search('\:.*[^_p](_?pcapc?\.[^(, ]+) *[(,]',line)
    methode=None
    fname=None
    if methmatch: methode=methmatch.group(1)
    if fnmatch: fname=fnmatch.group(1)
    if methode and fname:
        methods[methode]=fname
    else:
        # print 'warning: method(%s) fname(%s)\n\tline: %s' % ( methode, fname, line )
        pass

#print methods

# delete "_doc = _pcap" lines from global scope
# (they get moved in slightly different form to inside __init__ method).
for i in xrange(0,len(data)):
    # write out everything that is NOT a "_doc = _pcap" line.
    if not re.search('^[^ ]+_doc = _pcap.[^ ]+_doc$',data[i]):
        outfile.write(data[i])
    match=re.search('^\s*def __init__',data[i])
    if match:
        #print match.group(0)
        i=i+1
        break
# spit out the next 2 lines verbatim
#outfile.write(data[i])
#i=i+1
#outfile.write(data[i])
#i=i+1

# put doc assignments inside of the __init__
outfile.write('        import sys\n')
outfile.write('        if int(sys.version[0])>=\'2\':\n')
for method, fname in methods.items():
    outfile.write('            self.%s.im_func.__doc__ = %s.__doc__\n' % (method, fname))


# spit out rest of file verbatim
for i in xrange (i,len(data)):
    outfile.write(data[i])

outfile.close()
f.close()

os.system('mv %s.tmp %s' % (sys.argv[1], sys.argv[1]))
# vim:set ts=4 sw=4 et:



#! /usr/bin/env python

import pcap

def test_findalldevs():
    print pcap.findalldevs()
    for name, descr, addrs, flags in pcap.findalldevs():
        print 'Interface name: %s' % name
        print '   Description: %s ' % descr
        if addrs:
            i=1
            for ( addr, netmask, broadaddr, dstaddr) in addrs:
                print '    Address %d: %s ' % (i, addr)
                print '       Netmask: %s' % netmask
                print '     Broadcast: %s' % broadaddr
                print 'Peer dest addr: %s' % dstaddr
                i=i+1
        else:
            print ' No addresses'
        print ' flags: %s ' % flags

if __name__=="__main__":
    test_findalldevs()

# vim:set ts=4 sw=4 et:



#! /usr/bin/env python
"""
Example to sniff all HTTP traffic on eth0 interface:
    sudo ./sniff.py eth0 "port 80"
"""

import sys
import pcap
import string
import time
import socket
import struct

protocols={socket.IPPROTO_TCP:'tcp',
            socket.IPPROTO_UDP:'udp',
            socket.IPPROTO_ICMP:'icmp'}

def decode_ip_packet(s):
    d={}
    d['version']=(ord(s[0]) & 0xf0) >> 4
    d['header_len']=ord(s[0]) & 0x0f
    d['tos']=ord(s[1])
    d['total_len']=socket.ntohs(struct.unpack('H',s[2:4])[0])
    d['id']=socket.ntohs(struct.unpack('H',s[4:6])[0])
    d['flags']=(ord(s[6]) & 0xe0) >> 5
    d['fragment_offset']=socket.ntohs(struct.unpack('H',s[6:8])[0] & 0x1f)
    d['ttl']=ord(s[8])
    d['protocol']=ord(s[9])
    d['checksum']=socket.ntohs(struct.unpack('H',s[10:12])[0])
    d['source_address']=pcap.ntoa(struct.unpack('i',s[12:16])[0])
    d['destination_address']=pcap.ntoa(struct.unpack('i',s[16:20])[0])
    if d['header_len']>5:
        d['options']=s[20:4*(d['header_len']-5)]
    else:
        d['options']=None
    d['data']=s[4*d['header_len']:]
    return d


def dumphex(s):
    bytes = map(lambda x: '%.2x' % x, map(ord, s))
    for i in xrange(0,len(bytes)/16):
        print '        %s' % string.join(bytes[i*16:(i+1)*16],' ')
    print '        %s' % string.join(bytes[(i+1)*16:],' ')
        

def print_packet(pktlen, data, timestamp):
    if not data:
        return

    if data[12:14]=='\x08\x00':
        decoded=decode_ip_packet(data[14:])
        print '\n%s.%f %s > %s' % (time.strftime('%H:%M',
                                time.localtime(timestamp)),
                                timestamp % 60,
                                decoded['source_address'],
                                decoded['destination_address'])
        for key in ['version', 'header_len', 'tos', 'total_len', 'id',
                                'flags', 'fragment_offset', 'ttl']:
            print '    %s: %d' % (key, decoded[key])
        print '    protocol: %s' % protocols[decoded['protocol']]
        print '    header checksum: %d' % decoded['checksum']
        print '    data:'
        dumphex(decoded['data'])
 

if __name__=='__main__':

    if len(sys.argv) < 3:
        print 'usage: sniff.py <interface> <expr>'
        sys.exit(0)
    p = pcap.pcapObject()
    #dev = pcap.lookupdev()
    dev = sys.argv[1]
    net, mask = pcap.lookupnet(dev)
    # note:    to_ms does nothing on linux
    p.open_live(dev, 1600, 0, 100)
    #p.dump_open('dumpfile')
    p.setfilter(string.join(sys.argv[2:],' '), 0, 0)

    # try-except block to catch keyboard interrupt.    Failure to shut
    # down cleanly can result in the interface not being taken out of promisc.
    # mode
    #p.setnonblock(1)
    try:
        while 1:
            p.dispatch(1, print_packet)

        # specify 'None' to dump to dumpfile, assuming you have called
        # the dump_open method
        #    p.dispatch(0, None)

        # the loop method is another way of doing things
        #    p.loop(1, print_packet)

        # as is the next() method
        # p.next() returns a (pktlen, data, timestamp) tuple 
        #    apply(print_packet,p.next())
    except KeyboardInterrupt:
        print '%s' % sys.exc_type
        print 'shutting down'
        print '%d packets received, %d packets dropped, %d packets dropped by interface' % p.stats()
    


# vim:set ts=4 sw=4 et:



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.31
#
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _pcap
import new
new_instancemethod = new.instancemethod
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'PySwigObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


__doc__ = _pcap.__doc__
for dltname, dltvalue in _pcap.DLT.items():
  globals()[dltname] = dltvalue
del dltname, dltvalue


class pcapObject(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, pcapObject, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, pcapObject, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        import sys
        if int(sys.version[0])>='2':
            self.datalink.im_func.__doc__ = _pcap.pcapObject_datalink.__doc__
            self.fileno.im_func.__doc__ = _pcap.pcapObject_fileno.__doc__
            self.datalinks.im_func.__doc__ = _pcap.pcapObject_datalinks.__doc__
            self.major_version.im_func.__doc__ = _pcap.pcapObject_major_version.__doc__
            self.minor_version.im_func.__doc__ = _pcap.pcapObject_minor_version.__doc__
            self.getnonblock.im_func.__doc__ = _pcap.pcapObject_getnonblock.__doc__
            self.open_live.im_func.__doc__ = _pcap.pcapObject_open_live.__doc__
            self.dispatch.im_func.__doc__ = _pcap.pcapObject_dispatch.__doc__
            self.setnonblock.im_func.__doc__ = _pcap.pcapObject_setnonblock.__doc__
            self.stats.im_func.__doc__ = _pcap.pcapObject_stats.__doc__
            self.is_swapped.im_func.__doc__ = _pcap.pcapObject_is_swapped.__doc__
            self.open_dead.im_func.__doc__ = _pcap.pcapObject_open_dead.__doc__
            self.dump_open.im_func.__doc__ = _pcap.pcapObject_dump_open.__doc__
            self.next.im_func.__doc__ = _pcap.pcapObject_next.__doc__
            self.open_offline.im_func.__doc__ = _pcap.pcapObject_open_offline.__doc__
            self.snapshot.im_func.__doc__ = _pcap.pcapObject_snapshot.__doc__
            self.loop.im_func.__doc__ = _pcap.pcapObject_loop.__doc__
            self.setfilter.im_func.__doc__ = _pcap.pcapObject_setfilter.__doc__
        this = _pcap.new_pcapObject(*args)
        try: self.this.append(this)
        except: self.this = this
    def open_live(*args): return _pcap.pcapObject_open_live(*args)
    def open_dead(*args): return _pcap.pcapObject_open_dead(*args)
    def open_offline(*args): return _pcap.pcapObject_open_offline(*args)
    def dump_open(*args): return _pcap.pcapObject_dump_open(*args)
    def setnonblock(*args): return _pcap.pcapObject_setnonblock(*args)
    def getnonblock(*args): return _pcap.pcapObject_getnonblock(*args)
    def setfilter(*args): return _pcap.pcapObject_setfilter(*args)
    def loop(*args): return _pcap.pcapObject_loop(*args)
    def dispatch(*args): return _pcap.pcapObject_dispatch(*args)
    def next(*args): return _pcap.pcapObject_next(*args)
    def datalink(*args): return _pcap.pcapObject_datalink(*args)
    def datalinks(*args): return _pcap.pcapObject_datalinks(*args)
    def snapshot(*args): return _pcap.pcapObject_snapshot(*args)
    def is_swapped(*args): return _pcap.pcapObject_is_swapped(*args)
    def major_version(*args): return _pcap.pcapObject_major_version(*args)
    def minor_version(*args): return _pcap.pcapObject_minor_version(*args)
    def stats(*args): return _pcap.pcapObject_stats(*args)
    def fileno(*args): return _pcap.pcapObject_fileno(*args)
    __swig_destroy__ = _pcap.delete_pcapObject
    __del__ = lambda self : None;
pcapObject_swigregister = _pcap.pcapObject_swigregister
pcapObject_swigregister(pcapObject)

lookupdev = _pcap.lookupdev
findalldevs = _pcap.findalldevs
lookupnet = _pcap.lookupnet
aton = _pcap.aton
ntoa = _pcap.ntoa





# $Id: mk-constants.py,v 1.8 2012/01/05 10:15:27 wiml Exp $
#
# Python libpcap
# Copyright (C) 2004,2007 Wim Lewis
# Based on:
#   PY-libpcap (C) 1998, Aaron L. Rhodes
#   constants.i (C) 2001,2002, David Margrave
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the BSD Licence. See the file COPYING
# for details.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

linktypes = (
'DLT_NULL',
'DLT_EN10MB',
'DLT_EN3MB',
'DLT_AX25',
'DLT_PRONET',
'DLT_CHAOS',
'DLT_ARCNET',
'DLT_ARCNET_LINUX',
'DLT_SLIP',
'DLT_SLIP_BSDOS',
'DLT_FDDI',
'DLT_HIPPI',
'DLT_ATM_RFC1483',
'DLT_RAW',
'DLT_PPP',
'DLT_PPP_BSDOS',
'DLT_PPP_SERIAL',
'DLT_PPP_ETHER',
'DLT_C_HDLC',
# 'DLT_CHDLC',   # CHDLC is a compatibility alias for C_HDLC
'DLT_HDLC',
'DLT_ATM_CLIP',
'DLT_IEEE802',
'DLT_IEEE802_11',
'DLT_IEEE802_11_RADIO',
'DLT_IEEE802_11_RADIO_AVS',
'DLT_LOOP',
'DLT_LINUX_SLL',
'DLT_LTALK',
'DLT_ECONET',
'DLT_IPFILTER',
'DLT_PFLOG',
'DLT_PFSYNC',
'DLT_CISCO_IOS',
'DLT_PRISM_HEADER',
'DLT_AIRONET_HEADER',
'DLT_ENC',
'DLT_APPLE_IP_OVER_IEEE1394',
'DLT_AURORA',
'DLT_DOCSIS',
'DLT_FRELAY',
'DLT_IP_OVER_FC',
'DLT_JUNIPER_ATM1',
'DLT_JUNIPER_ATM2',
'DLT_JUNIPER_ES',
'DLT_JUNIPER_GGSN',
'DLT_JUNIPER_MFR',
'DLT_JUNIPER_MLFR',
'DLT_JUNIPER_MLPPP',
'DLT_JUNIPER_MONITOR',
'DLT_JUNIPER_SERVICES',
'DLT_LINUX_IRDA',
'DLT_RIO',
'DLT_SUNATM',
'DLT_SYMANTEC_FIREWALL',
'DLT_TZSP',
'DLT_REDBACK_SMARTEDGE',
'DLT_OLD_PFLOG',
'DLT_HHDLC',
'DLT_PCI_EXP',
'DLT_MTP2_WITH_PHDR',
'DLT_MTP2',
'DLT_MTP3',
'DLT_SCCP',
'DLT_IBM_SP',
'DLT_IBM_SN',
'DLT_BACNET_MS_TP',
'DLT_LINUX_PPP_WITHDIRECTION',   # Replaced by DLT_PPP_PPPD
'DLT_GPRS_LLC',
'DLT_GPF_T',
'DLT_GPF_F',
'DLT_GCOM_T1E1',
'DLT_GCOM_SERIAL',
'DLT_JUNIPER_PIC_PEER',
'DLT_ERF_ETH',
'DLT_ERF_POS',
'DLT_LINUX_LAPD',
'DLT_JUNIPER_ETHER',
'DLT_JUNIPER_PPP',
'DLT_JUNIPER_PPPOE',
'DLT_JUNIPER_PPPOE_ATM',
'DLT_JUNIPER_FRELAY',
'DLT_JUNIPER_CHDLC',
'DLT_JUNIPER_ISM',
'DLT_JUNIPER_ST',
'DLT_JUNIPER_VP',
'DLT_PPP_PPPD',
'DLT_MFR',
'DLT_A429',
'DLT_A653_ICM',
'DLT_USB',
'DLT_USB_LINUX',
'DLT_CAN20B',
'DLT_BLUETOOTH_HCI_H4',
'DLT_BLUETOOTH_HCI_H4_WITH_PHDR',
'DLT_IEEE802_16_MAC_CPS',
'DLT_IEEE802_16_MAC_CPS_RADIO',
'DLT_IEEE802_15_4_LINUX',
'DLT_IEEE802_15_4',
'DLT_PPI',
'DLT_SITA',
'DLT_ERF',
'DLT_RAIF1',
'DLT_IPMB',
'DLT_AX25_KISS',
'DLT_LAPD',
'DLT_PPP_WITH_DIR',
'DLT_C_HDLC_WITH_DIR',
'DLT_FRELAY_WITH_DIR',
'DLT_LAPB_WITH_DIR',
'DLT_IPMB_LINUX',
'DLT_FLEXRAY',
'DLT_MOST',
'DLT_LIN', 
'DLT_IEEE802_15_4_NONASK_PHY',
'DLT_GSMTAP_UM',
'DLT_GSMTAP_ABIS',
'DLT_MPLS',
'DLT_DECT',
'DLT_AOS',
'DLT_WIHART',
'DLT_FC_2',
'DLT_FC_2_WITH_FRAME_DELIMS',
'DLT_IPNET',
'DLT_CAN_SOCKETCAN',
'DLT_IPV4',
'DLT_IPV6',
'DLT_IEEE802_15_4_NOFCS',
'DLT_MUX27010',
'DLT_STANAG_5066_D_PDU',
'DLT_IPOIB',
)


import string
fp = open('constants.c', 'w')
fp.write('/* Automatically generated from\n')
rcs = '   $Id: mk-constants.py,v 1.8 2012/01/05 10:15:27 wiml Exp $\n'
fp.write(string.replace(rcs, '$', ''))
fp.write('   Do not edit this file directly, it will be overwritten \n*/\n\n')
fp.write('static struct { const char *name; long value; } ')
fp.write(' const pcapmodule_DLT[] = {\n')
for dlt in linktypes:
    fp.write('#ifdef %s\n' % (dlt,))
    fp.write('{ "%s", (%s) },\n' % (dlt,dlt))
    fp.write('#endif\n')
fp.write('{ NULL, 0 }\n};\n')

fp.close()




#! /usr/bin/env python

# $Id: setup.py,v 1.17 2012/01/06 00:13:13 wiml Exp $

import sys
import distutils.command.build
from distutils.command.build_ext import build_ext
from distutils.command.clean import clean
from distutils.core import setup, Extension, Command

import os

config_defines = [ ]
### CONFIGURATION ###

# uncomment this line and comment out the next one if you want to build
# pcap.c from the SWIG interface
# sourcefiles = ["mk-constants.py", "pcap.i"]
sourcefiles = ["pcap.c"]

# if you are building against a non-installed version of libpcap,
# specify its directory here, otherwise set this to None
libpcap_dir = None
# libpcap_dir = "/home/wiml/netsrc/libpcap/libpcap-0.7.2"
# libpcap_dir = "/home/wiml/netsrc/libpcap/libpcap-0.8.3"
# libpcap_dir = "/home/wiml/netsrc/libpcap/cvs.tcpdump.org/libpcap"

include_dirs = [ ]

# Depending on what version of libpcap you're using, you may need to
# uncomment one of these lines.

# Versions prior to 0.8 don't have pcap_lib_version().
# config_defines.append('WITHOUT_PCAP_LIB_VERSION')

# Versions prior to 0.8 don't have pcap_breakloop().
# config_defines.append('WITHOUT_BREAKLOOP')

# Versions prior to 0.7.2 or so don't have pcap_list_datalinks().
# config_defines.append('WITHOUT_LIST_DATALINKS')

# Some versions don't have pcap_version[].
# config_defines.append('WITHOUT_VERSION_STRING')


### END OF CONFIGURATION ###
# You shouldn't need to modify anything below this point unless you're
# doing development

sourcefiles += ["pcap_interface.c","exception.c","error.c"]


# I modified build_ext to add -shadow to the swig line.
# yay!

class pcapclean(clean):
    other_derived = [ 'pcap.py', 'pcap.c', 'constants.c', 'MANIFEST' ] 
    def run (self):
        #if self.all:
        for derived in self.other_derived:
            if os.access(derived, os.F_OK):
                print derived
                self.announce('removing: %s' % derived)
                if not self.dry_run:
                    os.unlink(derived)
        clean.run (self)
#        self.run_command('make_clean')

class pcap_build_ext(build_ext):

    def before_swig_sources(self, sources):
        new_sources = [ ]
        for source in sources:
            if source == 'mk-constants.py':
                self.make_file( (source,), 'constants.c', execfile, (source,) )
            else:
                new_sources.append(source)
        return new_sources
      
    def swig_sources(self, sources, extension=None):
    
        """Walk the list of source files in 'sources', looking for SWIG
        interface (.i) files.  Run SWIG on all that are found, and
        return a modified 'sources' list with SWIG source files replaced
        by the generated C (or C++) files.
        """

        sources = self.before_swig_sources(sources)
    
        new_sources = []
        swig_sources = []
        swig_targets = {}
    
        # XXX this drops generated C/C++ files into the source tree, which
        # is fine for developers who want to distribute the generated
        # source -- but there should be an option to put SWIG output in
        # the temp dir.
    
        if self.swig_cpp:
            target_ext = '.cpp'
        else:
            target_ext = '.c'
    
        for source in sources:
            (base, ext) = os.path.splitext(source)
            if ext == ".i":             # SWIG interface file
                new_sources.append(base + target_ext)
                swig_sources.append(source)
                swig_targets[source] = new_sources[-1]
            else:
                new_sources.append(source)
    
        if not swig_sources:
            return new_sources
    
        swig = self.find_swig()
        swig_cmd = [swig, "-Wall", "-python", "-shadow", "-ISWIG"]
        if self.swig_cpp:
            swig_cmd.append("-c++")
    
        for source in swig_sources:
            target = swig_targets[source]
            self.announce("swigging %s to %s" % (source, target))
            self.spawn(swig_cmd + ["-o", target, source])

            self.announce('doc-ifying swig-generated source file %s' % target)
            self.spawn([sys.executable, './build-tools/docify.py', target])

            self.announce('doc-ifying swig-generated shadow class file %s' % 'pcap.py')
            self.spawn([sys.executable, './build-tools/docify-shadow.py', 'pcap.py'])
    
        return new_sources

    # swig_sources ()

    def find_swig(self):
        if os.environ.has_key('SWIG'):
            return os.environ['SWIG']
        return build_ext.find_swig(self)
#

class build_shadowed (distutils.command.build.build):
    # this moves the 'build_py' subcommand to the end, so it happens
    # after the pcap.py module has been created by the build_ext command
    sub_commands = distutils.command.build.build.sub_commands
    sub_commands  = filter(lambda x: x[0] != 'build_py', sub_commands) + \
                    filter(lambda x: x[0] == 'build_py', sub_commands)


defines = [ ('SWIG_COBJECT_TYPES', None) ] + \
          map(lambda x: (x, None), config_defines)

if libpcap_dir is None:
    pcap_extension = Extension("_pcapmodule",
                                sourcefiles,
                                include_dirs = include_dirs,
                                define_macros = defines,
                                libraries = [ "pcap" ]
                                )
else:
    include_dirs.append( libpcap_dir )
    # extension_objects=[ os.path.join(libpcap_dir, 'libpcap.a') ]
    pcap_extension = Extension("_pcapmodule",
                                sourcefiles,
                                include_dirs = include_dirs,
                                define_macros = defines,
                                library_dirs = [ libpcap_dir ],
                                libraries = [ "pcap" ]
                                )
#



setup (# Distribution meta-data
        name = "pylibpcap",
        version = "0.6.4",
        license = "BSD",
        description = 'pylibpcap is a python module for the libpcap packet capture library.',
        long_description = 'pylibpcap is a python module for the libpcap packet capture library.',
        url = "http://pylibpcap.sourceforge.net/",
        author = "David Margrave",
        author_email = "davidma@eskimo.com",
        maintainer = "Wim Lewis",
        maintainer_email = "wiml@users.sourceforge.net",
        # keywords = "",
        # platforms = "",
        py_modules = [ "pcap" ],
        ext_modules = [ pcap_extension ],
        cmdclass = {'clean': pcapclean,
                    'build_ext': pcap_build_ext,
                    'build': build_shadowed},
        classifiers = [ 'Development Status :: 4 - Beta',
                        'Intended Audience :: Developers',
                        'Intended Audience :: System Administrators',
                        'License :: OSI Approved :: BSD License',
                        'Programming Language :: C',
                        'Programming Language :: Python',
                        'Topic :: Software Development :: Libraries :: Python Modules',
                        'Topic :: System :: Networking :: Monitoring' ],
      )

# vim:set ts=4 sw=4 et:
